from src.abstract_ai import *
input(isinstance({'api_response': 'Absolutely! Understanding the complexities requires in-depth exploration beyond this summary.', 'generate_title': 'Understanding_Complexities_In-Depth_Exploration'},dict))
result = make_general_query("""Absolutely! Understanding the complexitiesin-depth exploration beyond this summary.""")
input(result)
"""/home/computron/Documents/pythonTools/modules/abstract_ai/src/abstract_ai/gpt_classes/nogui_selection/query_all.py:from abstract_ai import *
/home/computron/Documents/pythonTools/modules/abstract_ai/src/abstract_ai/gpt_classes/nogui_selection/prompt_manager.py:from abstract_ai.gpt_classes.model_selection.ModelBuilder import ModelManager
/home/computron/Documents/pythonTools/modules/abstract_ai/src/abstract_ai/gpt_classes/nogui_selection/db_query.py:from abstract_ai import async_get_xlsx_file_path_from_response_vars
/home/computron/Documents/pythonTools/modules/abstract_ai/src/abstract_ai/ai_call_package/apis/make_api_calls.py:from abstract_ai import *
/home/computron/Documents/pythonTools/modules/abstract_ai/src/abstract_ai/specializations/database_query.py:from abstract_ai.gpt_classes.nogui_selection.general_query import make_general_query
/home/computron/Documents/pythonTools/modules/abstract_ai/src/abstract_ai/specializations/images/dalee_image_create.py:from abstract_ai.gpt_classes import ApiManager
"""
